==> aliyun-python-sdk-ft-test-1.11.11.tar.gz: aliyun-python-sdk-ft-test-1.11.11/aliyunsdkft/request/v20180713/FtDynamicAddressHttpVpcRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkft.endpoint import endpoint_data

class FtDynamicAddressHttpVpcRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ft', '2018-07-13', 'FtDynamicAddressHttpVpc')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StringValue(self):
		return self.get_query_params().get('StringValue')

	def set_StringValue(self,StringValue):
		self.add_query_param('StringValue',StringValue)

	def get_OtherParam(self):
		return self.get_query_params().get('OtherParam')

	def set_OtherParam(self,OtherParam):
		self.add_query_param('OtherParam',OtherParam)

	def get_BooleanParam(self):
		return self.get_query_params().get('BooleanParam')

	def set_BooleanParam(self,BooleanParam):
		self.add_query_param('BooleanParam',BooleanParam)

	def get_DefaultValue(self):
		return self.get_query_params().get('DefaultValue')

	def set_DefaultValue(self,DefaultValue):
		self.add_query_param('DefaultValue',DefaultValue)

==> aliyun-python-sdk-ft-test-1.23.3.tar.gz: aliyun-python-sdk-ft-test-1.23.3/aliyunsdkft/request/v20180713/FtDynamicAddressHttpVpcRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkft.endpoint import endpoint_data

class FtDynamicAddressHttpVpcRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ft', '2018-07-13', 'FtDynamicAddressHttpVpc')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_P1(self): # String
		return self.get_query_params().get('P1')

	def set_P1(self, P1):  # String
		self.add_query_param('P1', P1)
	def get_StringValue(self): # String
		return self.get_query_params().get('StringValue')

	def set_StringValue(self, StringValue):  # String
		self.add_query_param('StringValue', StringValue)
	def get_OtherParam(self): # String
		return self.get_query_params().get('OtherParam')

	def set_OtherParam(self, OtherParam):  # String
		self.add_query_param('OtherParam', OtherParam)
	def get_BooleanParam(self): # Boolean
		return self.get_query_params().get('BooleanParam')

	def set_BooleanParam(self, BooleanParam):  # Boolean
		self.add_query_param('BooleanParam', BooleanParam)
	def get_DefaultValue(self): # String
		return self.get_query_params().get('DefaultValue')

	def set_DefaultValue(self, DefaultValue):  # String
		self.add_query_param('DefaultValue', DefaultValue)
